#!/bin/bash
# packager           : Fred. Galusik <fredg> (fred~AT~zenwalk.fr)
# source location    : http://www.alsaplayer.org/
# last revised       : 04.11.2007

softname='alsaplayer'
softversion='0.99.80'
packageversion='50.1'

arch='i486'
cpu='i686'

prefix=/usr

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps/
mkdir -p $dest/usr/src/$softname-$softversion

# put slack-desc in place
cat <<EOF > $dest/install/slack-desc
   |-----handy-ruler------------------------------------------------------|
$softname: Lightweight Audio Player
$softname:
$softname: AlsaPlayer is a new type of PCM player. It is heavily multi-
$softname: threaded and tries to excercise the ALSA library and driver  
$softname: quite a bit.
$softname: 
$softname:
$softname:
$softname: 
$softname:
$softname:
EOF

# dowload the svn release
# svn co https://alsaplayer.svn.sourceforge.net/svnroot/alsaplayer/trunk/alsaplayer alsaplayer-$softversion

# extract the source code
cd $buildir
tar xjvf $srcpkg
cd $src
#./bootstrap

# build
    export CFLAGS="-O2 -march=$arch -mtune=$cpu"
    export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

    ./configure \
      --prefix=$prefix \
      --localstatedir=/var/lib \
      --mandir=$prefix/man \
      --docdir=$prefix/doc/$softname-$softversion \
      --enable-esd=no \
      --enable-oss=no \
      --program-prefix="" \
      --program-suffix="" \

    make
    make install DESTDIR=$dest

# add 'default' files
    cp -a \
      ABOUT-NLS AUTHORS COPYING ChangeLog INSTALL README TODO \
      $dest/usr/doc/$softname-$softversion
      
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# Make the package freedesktop compliant
cp $buildir/$softname.png $dest/usr/share/icons/hicolor/48x48/apps/

# ZenBuild and alsaplayer icon (found on the alsaplayer website)
cp -a \
  $buildir/build-$softname.sh $buildir/$softname.png \
  $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work:
cd $dest
makepkg -l y -c n $dest.tgz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.tgz > $package.md5
